@@ -21,6 +21,7 @@
 #include <QFile>
 #include <QTextStream>
 #include <QDebug>
+#include <QIcon>
 
 #include "defaultprovider.h"
 #include "kraftdb.h"
@@ -44,6 +45,13 @@ DefaultProvider::DefaultProvider()
 
 }
 
+QIcon DefaultProvider::icon(const QString& name)
+{
+    const QString fullIconName = QString(":kraft/custom-icons/%1.svg").arg(name);
+    const QIcon icon { fullIconName };
+    return icon;
+}
+
 QString DefaultProvider::docType()
 {
   QString type = KraftSettings::self()->doctype();
@@ -204,13 +212,7 @@ QString DefaultProvider::locateFile(const QString& findFile) const
     QString re;
     const QString kraftHome = QString::fromUtf8(qgetenv( "KRAFT_HOME" ));
 
-    auto dirs = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation);
-
-    if (kraftHome.isEmpty()) {
-        // prepend the kraft path segment and look in the system resources
-        QString fifi {findFile};
-        re = QStandardPaths::locate( QStandardPaths::AppDataLocation, fifi);
-    } else {
+    if (!kraftHome.isEmpty()){
         // KRAFT_HOME is set
         QString fifi {kraftHome};
         if (!fifi.endsWith('/') && !findFile.startsWith('/'))
@@ -233,6 +235,13 @@ QString DefaultProvider::locateFile(const QString& findFile) const
         }
     }
 
+    // check the system paths
+    if (re.isEmpty()) {
+        // prepend the kraft path segment and look in the system resources
+        QString fifi {findFile};
+        re = QStandardPaths::locate( QStandardPaths::AppDataLocation, fifi);
+    }
+
     if (re.isEmpty()) {
         qDebug() << "locateFile could not find file " << findFile;
     }
@@ -240,7 +249,7 @@ QString DefaultProvider::locateFile(const QString& findFile) const
     return re;
 }
 
-QString DefaultProvider::locateKraftTool(const QString& toolName) const
+QStringList DefaultProvider::locatePythonTool(const QString& toolName) const
 {
     QString fullPath;
 
@@ -257,80 +266,41 @@ QString DefaultProvider::locateKraftTool(const QString& toolName) const
     if (!fi.exists()) {
         fullPath.clear();
     }
-    return fullPath;
+
+    // -- check for python.
+    // Default is python3
+    // If Kraft is running from an AppImage, we rather use the python from conda which is
+    // installed in a relative path.
+    QString python {"python3"};
+    const QString pypath = QCoreApplication::applicationDirPath() + QStringLiteral("/../conda/bin/python");
+    QFileInfo fip(pypath);
+    if (fip.exists() && fip.isExecutable()) {
+        python = fip.canonicalFilePath();
+    }
+
+    QStringList rep {python, fullPath};
+    qDebug() << "Returning tool path" << rep;
+
+    return rep;
 }
 
 QString DefaultProvider::locateBinary(const QString& name) const
 {
-    QString bin;
-    if (!name.isEmpty()) {
-        bin = QStandardPaths::findExecutable( name );
+    // check the current app path and check if the binary is in there. (AppImage)
+    const QString path = QCoreApplication::applicationDirPath();
+    const QString localPrg = QString("%1/%2").arg(path).arg(name);
+    QFileInfo fi{localPrg};
+
+    if (fi.exists() && fi.isExecutable()) {
+        qDebug() << "Returning tool path" << fi.absoluteFilePath() << "for" << name;
+        return fi.absoluteFilePath();
     }
+
+    const QString bin = QStandardPaths::findExecutable( name );
+
     return bin;
 }
 
-
-QStringList DefaultProvider::findTrml2Pdf( ) const
-{
-    // define the default value to compare against, to see if there is a custom
-    // value in the settings file.
-    const QString rmlbinDefault = QStringLiteral( "trml2pdf" ); // FIXME: how to get the default value?
-    const QString rmlbin = KraftSettings::self()->trml2PdfBinary();
-
-    // qDebug () << "### Start searching rml2pdf bin: " << rmlbin;
-
-    QStringList retList;
-    // mHavePdfMerge = false;
-
-    if ( rmlbin != rmlbinDefault ) {
-        retList = rmlbin.split(' ', QString::SkipEmptyParts);
-    } else {
-        // The value in the config is not, as it is still the same as the default
-        // read from either KRAFT_HOME or search in the system.
-        QString p = QString::fromUtf8(qgetenv("KRAFT_HOME"));
-        if( !p.isEmpty() ) {
-            p += QLatin1String("/tools/erml2pdf.py");
-            // qDebug () << "Found erml2pdf from KRAFT_HOME: " << p;
-            if( QFile::exists( p ) ) {
-                retList << "python3";
-                retList << p;
-                // mHavePdfMerge = true;
-            }
-        } else {
-            const QString ermlpy = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kraft/tools/erml2pdf.py" );
-            // qDebug () << "Ermlpy: " << ermlpy;
-            if( ! ermlpy.isEmpty() ) {
-                // need the python3 interpreter, check for it
-                QString python = QStandardPaths::findExecutable(QLatin1String("python3"));
-                if( python.isEmpty() ) {
-                    qCritical() << "ERR: Unable to find python3, thats a problem";
-                } else {
-                    // qDebug () << "Using python: " << python;
-                    retList << python;
-                    retList << ermlpy;
-                    // mHavePdfMerge = true;
-                }
-            }
-        }
-        if (retList.isEmpty() ){
-            // tool erml2pdf.py not found. Try trml2pdf_kraft.sh for legacy reasons
-            QString trml2pdf = QStandardPaths::findExecutable(QLatin1String("trml2pdf_kraft.sh"));
-            if( trml2pdf.isEmpty() ) {
-                // qDebug () << "Could not find trml2pdf_kraft.sh";
-            } else {
-                // qDebug () << "Found trml2pdf: " << trml2pdf;
-                retList << trml2pdf;
-                // mHavePdfMerge = true;
-            }
-        }
-    }
-    if ( retList.isEmpty() ) {
-        qDebug () << "ReportLab based PDF conversion script not found!";
-    }
-
-    return retList;
-}
-
 bool DefaultProvider::writeXmlArchive()
 {
     return KraftSettings::self()->doXmlArchive();
