@@ -28,6 +28,7 @@
 #include "ui_positionwidget.h"
 #include "positionviewwidget.h"
 #include "defaultprovider.h"
+#include "tagman.h"
 
 /**
 @author Klaas Freitag
@@ -122,61 +123,94 @@ QString DocPositionBase::attribute( const QString& attName ) const
   return att.value().toString();
 }
 
+// The attribs tag contains a list of TagIDs separated by commas
 void DocPositionBase::setTag( const QString& tag )
 {
-  if ( tag.isEmpty() ) return;
+    if ( tag.isEmpty() ) return;
 
-  if ( mAttribs.contains( DocPosition::Tags ) ) {
-    if ( hasTag( tag ) ) return;
-    Attribute att = mAttribs[DocPosition::Tags];
-    QStringList li =  att.value().toStringList();
+    Attribute att;
+    att.setPersistant(true);
 
-    li.append( tag );
-    att.setValue( QVariant( li ) );
+    if ( mAttribs.contains( DocPosition::Tags ) ) {
+        if ( hasTag( tag ) ) {
+            return;
+        }
+
+        att = mAttribs[DocPosition::Tags];
+    } else {
+        att = Attribute(DocPosition::Tags);
+    }
+    att.setListValue(true);
+
+    // here: the attribute does not have the new tag.
+    QStringList li = att.value().toStringList();
+    li.append(TagTemplateMan::self()->getTagTemplate(tag).dbId().toString());
+    att.setValue( QVariant(li) );
     setAttribute( att );
-  } else {
+}
+
+void DocPositionBase::replaceTags(const QStringList& newTags)
+{
+    if (newTags.isEmpty()) {
+        if (mAttribs.contains(DocPosition::Tags)) {
+            removeAttribute(DocPosition::Tags);
+        }
+        return;
+    }
+
+    Attribute att = Attribute(DocPosition::Tags);
+    att.setPersistant(true);
+    att.setListValue(true);
+
     QStringList li;
-    li.append( tag );
-    Attribute a( DocPosition::Tags );
-    a.setValueRelation( "tagTemplates", "tagTmplID", "name" );
-    a.setListValue( true );
-    a.setPersistant( true );
-    a.setValue( QVariant( li ) );
-    setAttribute( a );
-  }
+    for( const QString& tag : newTags ) {
+        li.append(TagTemplateMan::self()->getTagTemplate(tag).dbId().toString());
+    }
+    att.setValue( QVariant(li) );
+    setAttribute( att );
 }
 
 void DocPositionBase::removeTag( const QString& tag )
 {
-  if ( hasTag( tag ) ) {
+    if ( !hasTag( tag ) ) {
+        return;
+    }
+
+    const QString tagId = TagTemplateMan::self()->getTagTemplate(tag).dbId().toString();
+
     Attribute att = mAttribs[DocPosition::Tags];
     QStringList li =  att.value().toStringList();
 
-    li.removeAll( tag );
+    li.removeAll( tagId );
     att.setValue( QVariant( li ) );
     setAttribute( att );
-  }
 }
 
 bool DocPositionBase::hasTag( const QString& tag )
 {
-  if ( ! mAttribs.contains( DocPosition::Tags ) ) {
+    const QString tagId = TagTemplateMan::self()->getTagTemplate(tag).dbId().toString();
+
+    if ( ! mAttribs.contains( DocPosition::Tags ) ) {
+        return false;
+    }
+    Attribute att = mAttribs[DocPosition::Tags];
+    QStringList li =  att.value().toStringList();
+    if( li.contains( tagId, Qt::CaseInsensitive ) && // ignore case
+            !att.isMarkedDeleted() ) {
+        return true;
+    }
     return false;
-  }
-  Attribute att = mAttribs[DocPosition::Tags];
-  QStringList li =  att.value().toStringList();
-  if( li.contains( tag, Qt::CaseInsensitive ) ) { // ignore case
-    return true;
-  }
-  return false;
 }
 
 QStringList DocPositionBase::tags()
 {
-  QStringList tags;
+  QStringList tags, tagIDs;
   if ( mAttribs.contains( DocPosition::Tags ) ) {
     // qDebug () << mAttribs[DocPosition::Tags].toString() << endl;
-    tags = mAttribs[DocPosition::Tags].value().toStringList();
+    tagIDs = mAttribs[DocPosition::Tags].value().toStringList();
+  }
+  for( const auto &tagId : tagIDs) {
+      tags.append(TagTemplateMan::self()->getTagTemplateFromId(tagId).name());
   }
   return tags;
 }
@@ -233,11 +267,15 @@ Geld DocPosition::overallPrice()
 {
     Geld g;
     AttributeMap atts = attributes();
-    // all kinds beside from no kind mean  that the position is not
-    // counted for the overall price. That's a FIXME
-    if ( ! atts.contains( DocPosition::Kind ) ) {
-      g = unitPrice() * amount();
+
+    // all kinds beside from no kind (which means Normal) mean that the position is not
+    // counted for the overall price.
+    // Once there are kinds different from Normal which need a counted price, this needs
+    // to be fixed here.
+    if (!atts.containsUndeleted(DocPosition::Kind) ) {
+        g = unitPrice() * amount();
     }
+
     return g;
 }
 
@@ -262,7 +300,9 @@ Geld DocPositionList::nettoPrice()
 
   DocPositionListIterator it( *this );
   while( it.hasNext() ) {
-    g += static_cast<DocPosition*>(it.next())->overallPrice();
+      DocPosition *dp = static_cast<DocPosition*>(it.next());
+      if (!dp->toDelete())
+          g += dp->overallPrice();
   }
   return g;
 }
@@ -278,7 +318,7 @@ Geld DocPositionList::fullTaxSum( double fullTax )
   while( it.hasNext() ) {
     DocPosition *dp = static_cast<DocPosition*>( it.next() );
 
-    if( dp->taxTypeNumeric() == DocPositionBase::TaxFull ) {
+    if( !dp->toDelete() && dp->taxTypeNumeric() == DocPositionBase::TaxFull ) {
         sum += dp->overallPrice();
     }
   }
@@ -302,7 +342,7 @@ Geld DocPositionList::reducedTaxSum( double reducedTax )
   while( it.hasNext() ) {
     DocPosition *dp = static_cast<DocPosition*>( it.next() );
 
-    if( dp->taxTypeNumeric() == DocPositionBase::TaxReduced ) {
+    if( !dp->toDelete() && dp->taxTypeNumeric() == DocPositionBase::TaxReduced ) {
         sum += dp->overallPrice();
     }
   }
@@ -333,6 +373,7 @@ QString DocPositionList::posNumber( DocPositionBase* pos )
   return QString::number( 1+indexOf( pos ) );
 }
 
+#if 0
 QDomElement DocPositionList::domElement( QDomDocument& doc )
 {
   QDomElement topElem = doc.createElement( "positions" );
@@ -369,6 +410,7 @@ QDomElement DocPositionList::domElement( QDomDocument& doc )
   }
   return topElem;
 }
+#endif
 
 int DocPositionList::compareItems ( DocPosition *dp1, DocPosition *dp2 )
 {
