@@ -58,15 +58,15 @@ class KRAFTCAT_EXPORT DocType
   QStringList follower();
   int setAllFollowers( const QStringList& followers);
 
-  QString     generateDocumentIdent( const QDate& docDate, const QString& docType,
-                                     const QString& addressUid, int id = -1 );
+  QString     generateDocumentIdent(const QDate& docDate,
+                                    const QString& addressUid,
+                                    int id, int dayCnt);
   QString     identTemplate();
   void        setIdentTemplate( const QString& );
 
   QString     numberCycleName();
   void        setNumberCycleName( const QString& );
 
-  QString     defaultTemplateFile() const;
   QString     templateFile();
   void        setTemplateFile( const QString& );
 
@@ -79,12 +79,17 @@ class KRAFTCAT_EXPORT DocType
   QString     xRechnungTemplate();
   void        setXRechnungTemplate(const QString&);
 
+  QString     appendPDF() const;
+  void        setAppendPDFFile(const QString& file);
+
   void        setAttribute( const QString& attribute, const QString& val);
-  QString     attributeValueString(const QString& attribName);
+  QString     attributeValueString(const QString& attribName) const;
 
   static void  clearMap();
 
   int         nextIdentId( bool hot = true );
+  int         nextDayCounter(const QDate& docDate);
+
   void        save();
 
   void        readIdentTemplate();
@@ -102,7 +107,6 @@ private:
   QString      mIdentTemplate;
   bool         mDirty;
   QString      mMergeIdent;
-
   static idMap mNameMap;
 };
 
