@@ -16,10 +16,12 @@
  ***************************************************************************/
 
 #include "documenttemplate.h"
+#include "epcqrcode.h"
 #include "texttemplate.h"
 #include "grantleetemplate.h"
 #include "format.h"
 #include "kraftsettings.h"
+#include "version.h"
 
 #include <klocalizedstring.h>
 
@@ -28,7 +30,7 @@
 
 // ==================================================================================
 
-namespace  {
+namespace {
 
 QString escapeTrml2pdfXML( const QString& str )
 {
@@ -101,7 +103,6 @@ QVariantHash contactToVariantHash(const KContacts::Addressee& contact )
                  escapeTrml2pdfXML( address.region() ) );
     hash.insert( QStringLiteral("LABEL" ),
                  escapeTrml2pdfXML( address.label() ) );
-
     return hash;
 }
 
@@ -117,6 +118,7 @@ QVariantHash labelVariantHash()
     hash.insert( TAG( "SUM"), i18nc("Printed on the document", "Sum") );
     hash.insert( TAG( "NET"), i18nc("printed on the document", "Net") );
     hash.insert( TAG( "VAT"), i18nc("Printed on the document", "VAT") );
+    hash.insert( TAG( "TYPE"), i18nc("Document type, printed on the document", "Type") );
 
     hash.insert( TAG( "PHONE"), i18nc("Printed on the document", "Phone"));
     hash.insert( TAG( "FAX"), i18nc("Printed on the document", "FAX"));
@@ -133,6 +135,29 @@ QVariantHash labelVariantHash()
     hash.insert( TAG( "CUST_ID"), i18nc("Customer ID on document", "Customer Id"));
     hash.insert( TAG( "CURRENCY_SIGN"), DefaultProvider::self()->currencySymbol());
 
+    return hash;
+}
+
+QVariantHash kraftVariantHash()
+{
+    QVariantHash hash;
+    QString h = QString("Kraft %1 %2").arg(KRAFT_VERSION).
+            arg(KRAFT_CODENAME);
+    hash.insert(TAG("VERSION"), h);
+
+    h = QString("DB-Scheme %1").arg(KRAFT_REQUIRED_SCHEMA_VERSION);
+    hash.insert(TAG("DB_SCHEME"), h);
+
+    h = qgetenv("USER");
+    if (h.isEmpty())
+        h = qgetenv("USERNAME");
+    hash.insert(TAG("SYS_USER"), h);
+
+    h = qgetenv("HOSTNAME");
+    if (h.isEmpty())
+        h = qgetenv("HOST");
+    if (!h.isEmpty())
+        hash.insert(TAG("HOSTNAME"), h);
 
     return hash;
 }
@@ -162,6 +187,34 @@ void addLabelsToTemplate(TextTemplate& tmpl)
     variantHashToTemplate(tmpl, QStringLiteral("LAB"), hash);
 }
 
+QString generateEPCQRCodeFile(ArchDoc *archDoc)
+{
+    QString tempFile;
+    if (!archDoc) return tempFile;
+
+    const QString bacName = KraftSettings::self()->bankAccountName();
+    const QString bacIBAN = KraftSettings::self()->bankAccountIBAN();
+    const QString bacBIC  = KraftSettings::self()->bankAccountBIC();
+    EPCQRCode qrCode;
+    const QString reason = i18nc("Credit Transfer reason string, 1=DocType, 2=DocIdent, 3=Date, ie. Invoice 2022-183 dated 2022-03-22",
+                                 "%1 %2 dated %3",archDoc->docTypeStr(), archDoc->ident(), archDoc->dateStr());
+    const QString svgText = qrCode.asSvg(archDoc->bruttoSum(), bacName, bacBIC, bacIBAN, reason);
+
+    // -- save the EPC QR Code to a temp file
+    if (svgText.isEmpty()) {
+        qWarning() << "Failed to generate SVG text";
+    } else {
+        QTemporaryFile tFile(QString("%1/XXXXXX.svg").arg(QDir::tempPath()));
+        tFile.setAutoRemove(false);
+        if (tFile.open()) {
+            tempFile = tFile.fileName();
+            QTextStream stream(&tFile);
+            stream << svgText;
+            tFile.close();
+        }
+    }
+    return tempFile;
+}
 }
 
 // ==================================================================================
@@ -339,8 +392,30 @@ const QString CTemplateDocumentTemplate::expand(ArchDoc *archDoc, const KContact
 
     addLabelsToTemplate(tmpl);
 
+#if 0
+    /* this is still disabled as reportlab can not read SVG files
+     * When it can or the EPC QR Code can be generated as PNG, this needs to be added
+     * to the template:
+     *
+     *   {{#EPC_QR_CODE}}
+     *    <hr/>
+     *    <illustration width="120" height="120">
+     *      <image x="5" y="5" width="110" height="110" file="{{SVG_FILE_NAME}}" />
+     *    </illustration>
+     *    {{/EPC_QR_CODE}}
+     */
+
+    QString qrcodefile;
+    if (archDoc->isInvoice()) {
+        qrcodefile = generateEPCQRCodeFile(archDoc);
+        _tmpFiles.append(qrcodefile);
+        tmpl.createDictionary( DICT( "EPC_QR_CODE" ) );
+        tmpl.setValue( DICT("EPC_QR_CODE"), TAG( "SVG_FILE_NAME" ), qrcodefile);
+    }
+#endif
     // finalize the template
     const QString output = tmpl.expand();
+
     return output;
 }
 
@@ -374,10 +449,39 @@ const QString GrantleeDocumentTemplate::expand( ArchDoc *archDoc,
 
         gtmpl.addToObjMapping("doc", archDoc);
 
-        gtmpl.addToMapping(QStringLiteral("me"), contactToVariantHash(myContact));
-        gtmpl.addToMapping(QStringLiteral("customer"), contactToVariantHash(customerContact));
+        const auto mtt = contactToVariantHash(myContact);
+        gtmpl.addToMappingHash(QStringLiteral("me"), mtt);
+
+        const auto cct = contactToVariantHash(customerContact);
+        gtmpl.addToMappingHash(QStringLiteral("customer"), cct);
+
         const QVariantHash labelHash = labelVariantHash();
-        gtmpl.addToMapping(QStringLiteral("label"), labelHash);
+        gtmpl.addToMappingHash(QStringLiteral("label"), labelHash);
+
+        const QString bacName = KraftSettings::self()->bankAccountName();
+        const QString bacIBAN = KraftSettings::self()->bankAccountIBAN();
+        const QString bacBIC  = KraftSettings::self()->bankAccountBIC();
+        EPCQRCode qrCode;
+        const QString reason = i18nc("Credit Transfer reason string, 1=DocType, 2=DocIdent, 3=Date, ie. Invoice 2022-183 dated 2022-03-22",
+                                     "%1 %2 dated %3",archDoc->docTypeStr(), archDoc->ident(), archDoc->dateStr());
+
+        // -- save the EPC QR Code which is written into a temp file
+        QVariantHash epcHash;
+        auto qrcodefile = generateEPCQRCodeFile(archDoc);
+        epcHash.insert("valid", false);
+        if (qrcodefile.isEmpty()) {
+            qDebug() << "No Giro Code file available.";
+        } else {
+            _tmpFiles.append(qrcodefile); // remember file to delete later.
+            qDebug() << "Generated Giro Code file" << qrcodefile;
+
+            epcHash.insert("svgfilename", QVariant(qrcodefile));
+            epcHash["valid"] = true;
+            gtmpl.addToMappingHash(QStringLiteral("epcqrcode"), epcHash);
+        }
+        const QVariantHash kraftHash = kraftVariantHash();
+        gtmpl.addToMappingHash(QStringLiteral("kraft"), kraftHash);
+
         bool ok;
         rendered = gtmpl.render(ok);
         if (!ok) {
