@@ -36,17 +36,22 @@
 
 int main(int argc, char *argv[])
 {
-    KLocalizedString::setApplicationDomain("kraft");
     Q_INIT_RESOURCE(kraft);
+    const QByteArray domain {"kraft"};
 
     qRegisterMetaType<ArchDocPositionList>("ArchDocPositionList");
 
     QApplication app(argc, argv);
-    app.setWindowIcon(QIcon(":/kraft/global/32-apps-kraft.png"));
+    app.setWindowIcon(QIcon(":/kraft/custom-icons/kraft-simple.svg"));
     app.setApplicationName("kraft");
     app.setApplicationDisplayName("Kraft");
     app.setApplicationVersion(QString("version %1").arg(KRAFT_VERSION));
 
+    const QString path = QCoreApplication::applicationDirPath()+ QStringLiteral("/../share/locale");
+    qDebug() << "Setting additional Locale path:" << path;
+    KLocalizedString::setApplicationDomain(domain.data());
+    KLocalizedString::addDomainLocaleDir(domain, path);
+
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
