@@ -29,6 +29,7 @@
 #include "docposition.h"
 #include "kataloglistview.h"
 #include "kraftsettings.h"
+#include "format.h"
 
 MaterialKatalogListView::MaterialKatalogListView(QWidget *parent )
   : KatalogListView( parent )
@@ -45,7 +46,7 @@ MaterialKatalogListView::MaterialKatalogListView(QWidget *parent )
 
   setHeaderLabels( headers );
 
-  QByteArray headerState = QByteArray::fromBase64( KraftSettings::self()->materialCatViewHeader().toAscii() );
+  QByteArray headerState = QByteArray::fromBase64( KraftSettings::self()->materialCatViewHeader().toLatin1() );
   header()->restoreState(headerState);
   contextMenu()->setTitle(i18n("Material Catalog"));
 }
@@ -67,20 +68,24 @@ void MaterialKatalogListView::addCatalogDisplay( const QString& katName )
   // qDebug () << "setting up meterial chapters --------*********************************+++!" << endl;
   setupChapters();
 
-  const QList<CatalogChapter> chapters = catalog->getKatalogChapters();
-  foreach( CatalogChapter theChapter, chapters ) {
-    if( mChapterDict.contains( theChapter.id().toInt() ) ) {
-      QTreeWidgetItem *katItem = mChapterDict[theChapter.id().toInt()];
-
-      // hole alle Brunsrecords per Chapter und mach weiter....
-      StockMaterialList records = catalog->getRecordList( theChapter );
-      StockMaterialListIterator it( records );
-      while( it.hasNext() ) {
-        StockMaterial *mat = it.next();
-        addMaterialToView( katItem,  mat );
+  // lambda expression to be DRY
+  auto insertRecords = [&]( int chapterId) {
+      StockMaterialList records = catalog->getRecordList(chapterId);
+      QTreeWidgetItem *chapterItem = m_root;
+      if (mChapterDict.contains(chapterId))
+          chapterItem = mChapterDict[chapterId];
+      for( StockMaterial *mat: records) {
+          addMaterialToView( chapterItem, mat );
       }
-    }
+  };
+
+  for( int chapterId : mChapterDict.keys()) {
+      insertRecords(chapterId);
   }
+
+  // append the stray cats
+  insertRecords(0);
+
 }
 
 QTreeWidgetItem* MaterialKatalogListView::addMaterialToView( QTreeWidgetItem *parent, StockMaterial *mat )
@@ -89,7 +94,6 @@ QTreeWidgetItem* MaterialKatalogListView::addMaterialToView( QTreeWidgetItem *pa
   if ( !parent ) parent = m_root;
 
   QTreeWidgetItem *recItem = new QTreeWidgetItem( parent );
-  Qt::ItemFlags flags;
   if ( mCheckboxes ) {
     recItem->setCheckState(0, Qt::Unchecked);
   }
@@ -102,8 +106,9 @@ QTreeWidgetItem* MaterialKatalogListView::addMaterialToView( QTreeWidgetItem *pa
   return recItem;
 }
 
-void MaterialKatalogListView::slFreshupItem( QTreeWidgetItem *item, void* templ, QLocale *loc )
+void MaterialKatalogListView::slFreshupItem(QTreeWidgetItem *item, void* templ, QLocale *loc)
 {
+    Q_UNUSED(loc)
   StockMaterial *mat = static_cast<StockMaterial*>( templ );
 
   if ( item && mat ) {
@@ -112,9 +117,9 @@ void MaterialKatalogListView::slFreshupItem( QTreeWidgetItem *item, void* templ,
     item->setText( 0, mat->getText() );
     item->setText( 1, QString::number( mat->getAmountPerPack() ) );
     item->setText( 2, e.einheit( mat->getAmountPerPack() ) );
-    item->setText( 3, mat->purchPrice().toString() );
-    item->setText( 4, mat->salesPrice().toString() );
-    item->setText( 5, mat->lastModified() );
+    item->setText( 3, mat->purchPrice().toLocaleString() );
+    item->setText( 4, mat->salesPrice().toLocaleString() );
+    item->setText( 5, Format::toDateTimeString( mat->modifyDate(), KraftSettings::self()->dateFormat()));
   } else {
     // qDebug () << "Unable to freshup item - data invalid" << endl;
   }
@@ -147,3 +152,20 @@ void MaterialKatalogListView::saveState()
     KraftSettings::self()->setMaterialCatViewHeader(state.toBase64());
 }
 
+void MaterialKatalogListView::startUpdateItemSequence()
+{
+    _query = new QSqlQuery;
+    _query->prepare("UPDATE stockMaterial SET sortKey = :sk WHERE matID=:id");
+}
+
+void MaterialKatalogListView::updateItemSequence(QTreeWidgetItem *item, int seqNo)
+{
+    StockMaterial *mat = static_cast<StockMaterial*>( m_dataDict[item] );
+    if ( mat ) {
+        int id = mat->getID();
+        _query->bindValue(":id", id);
+        _query->bindValue(":sk", seqNo);
+        _query->exec();
+    }
+}
+
