@@ -20,9 +20,12 @@
 
 #include <QMap>
 #include <QLabel>
+#include <QWizard>
 
 #include <kcontacts/addressee.h>
-#include <kassistantdialog.h>
+
+#include "kraftdoc.h"
+#include "docguardedptr.h"
 
 class DocText;
 class TextSelection;
@@ -32,13 +35,14 @@ class QDateEdit;
 class QComboBox;
 class QHBox;
 class QTextEdit;
+class QCheckBox;
 
 using namespace KContacts;
 
 
 // ---------------------------------------------------------------------------
 
-class CustomerSelectPage: public QWidget
+class CustomerSelectPage: public QWizardPage
 {
   Q_OBJECT
 
@@ -61,7 +65,7 @@ private:
 
 // ---------------------------------------------------------------------------
 
-class DocDetailsPage : public QWidget
+class DocDetailsPage : public QWizardPage
 {
   Q_OBJECT
 
@@ -71,22 +75,27 @@ public:
   DocDetailsPage( QWidget *parent = 0 );
   ~DocDetailsPage();
 
+  void setNoAddresses();
+
 private:
+  bool        _haveAddressSelect;
   QLabel      *mCustomerLabel;
   QDateEdit   *mDateEdit;
   QComboBox   *mTypeCombo;
   QTextEdit   *mWhiteboardEdit;
+  QCheckBox   *mKeepItemsCB;
+  QComboBox   *mSourceDocIdentsCombo;
 };
 
 // ---------------------------------------------------------------------------
 
-class KraftWizard: public KAssistantDialog
+class KraftWizard: public QWizard
 {
   Q_OBJECT
 
 public:
   KraftWizard(QWidget *parent = 0, const char* name = 0, bool modal = false );
-  void init();
+  void init(bool haveAddressSelect, const QString& followUpDoc = QString());
 
   ~KraftWizard();
 
@@ -95,9 +104,10 @@ public:
   QString docType() const;
   QString whiteboard() const;
   void setCustomer( const QString& );
-  void setDocIdentifier( const QString& );
+  void setDocToFollow( DocGuardedPtr sourceDoc);
   void setAvailDocTypes( const QStringList& );
   void done(int r);
+  QString copyItemsFromPredecessor();
 
 protected slots:
   void slotAddressee( const KContacts::Addressee& );
@@ -109,9 +119,6 @@ private:
   QWidget *mParent;
 
   KContacts::Addressee mAddressee;
-
-  KPageWidgetItem *mCustomerPageItem;
-  KPageWidgetItem *mDetailsPageItem;
 };
 
 #endif
