@@ -49,7 +49,6 @@
 #include "katalog.h"
 #include "katalogman.h"
 #include "kraftdoc.h"
-#include "floskeltemplate.h"
 #include "templkatalogview.h"
 #include "materialkatalogview.h"
 #include "prefsdialog.h"
@@ -77,6 +76,9 @@ Portal::Portal(QWidget *parent, QCommandLineParser *commandLineParser, const cha
   setObjectName( name );
   _readOnlyMode = mCmdLineArgs->isSet("r");
 
+  const QStringList iconPaths {":kraft/custom-icons"};
+  QIcon::setFallbackSearchPaths(iconPaths);
+
   ///////////////////////////////////////////////////////////////////
   // call inits to invoke all other construction parts
   initActions();
@@ -99,95 +101,97 @@ Portal::Portal(QWidget *parent, QCommandLineParser *commandLineParser, const cha
 void Portal::initActions()
 {
     QIcon newIcon;
-    newIcon = QIcon::fromTheme( "application-exit");
+    newIcon = DefaultProvider::self()->icon( "logout");
     _actFileQuit = new QAction(newIcon, i18n("&Quit"), this);
     _actFileQuit->setShortcuts(QKeySequence::Quit);
     connect(_actFileQuit, &QAction::triggered, this, &QWidget::close);
 
-    newIcon = QIcon::fromTheme( "edit-cut");
+    newIcon = DefaultProvider::self()->icon( "cut");
     _actEditCut = new QAction(newIcon, i18n("&Cut"), this);
     _actEditCut->setShortcuts(QKeySequence::Cut);
     connect(_actEditCut, &QAction::triggered, this, &Portal::slotEditCut);
 
-    newIcon = QIcon::fromTheme( "edit-copy");
+    newIcon = DefaultProvider::self()->icon( "copy");
     _actEditCopy = new QAction(newIcon, i18n("C&opy"), this);
     _actEditCopy->setShortcuts(QKeySequence::Copy);
     connect(_actFileQuit, &QAction::triggered, this, &Portal::slotEditCopy);
 
-    newIcon = QIcon::fromTheme( "edit-paste");
+    newIcon = DefaultProvider::self()->icon( "transfer-in");
     _actEditPaste = new QAction(newIcon, i18n("&Paste"), this);
     _actEditPaste->setShortcuts(QKeySequence::Paste);
     connect(_actEditPaste, &QAction::triggered, this, &Portal::slotEditPaste);
 
-    newIcon = QIcon::fromTheme( "settings-configure");
+    newIcon = DefaultProvider::self()->icon( "settings");
     _actPreferences = new QAction(newIcon, i18n("&Settings"), this);
     _actPreferences->setShortcuts(QKeySequence::Preferences);
     connect(_actPreferences, &QAction::triggered, this, &Portal::preferences);
 
-    newIcon = QIcon::fromTheme( "document-new");
+    newIcon = DefaultProvider::self()->icon( "file-plus");
     _actNewDocument = new QAction(newIcon, i18n("&Create Document"), this);
     _actNewDocument->setShortcuts(QKeySequence::New);
     connect(_actNewDocument, &QAction::triggered, this, &Portal::slotNewDocument);
 
-    newIcon = QIcon::fromTheme( "document-new-from-template");
+    newIcon = DefaultProvider::self()->icon( "template");
     _actCopyDocument = new QAction(newIcon, i18n("&Copy Document"), this);
     // _actCopyDocument->setShortcuts();
     connect(_actCopyDocument, &QAction::triggered, this, &Portal::slotCopyCurrentDocument);
 
-    newIcon = QIcon::fromTheme( "document-export");
+    newIcon = DefaultProvider::self()->icon( "file-export");
     _actFollowDocument = new QAction(newIcon, i18n("Create &Followup Document"), this);
     _actFollowDocument->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_F ));
     connect(_actFollowDocument, &QAction::triggered, this, &Portal::slotFollowUpDocument);
 
-    newIcon = QIcon::fromTheme( "document-print");
+    newIcon = DefaultProvider::self()->icon( "printer");
     _actPrintDocument = new QAction(newIcon, i18n("Print Document"), this);
     _actPrintDocument->setShortcut( QKeySequence::Print);
     connect(_actPrintDocument, &QAction::triggered, this, &Portal::slotPrintCurrentDocument);
 
-    newIcon = QIcon::fromTheme( "document-preview");
+    newIcon = DefaultProvider::self()->icon( "eye");
     _actViewDocument = new QAction(newIcon, i18n("Show Document"), this);
     _actViewDocument->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_R ));
     connect(_actViewDocument, &QAction::triggered, this, &Portal::slotViewCurrentDocument);
 
-    newIcon = QIcon::fromTheme( "document-edit");
+    newIcon = DefaultProvider::self()->icon( "edit");
     _actOpenDocument = new QAction(newIcon, i18n("Edit Document"), this);
     _actOpenDocument->setShortcut( QKeySequence::Open );
     connect(_actOpenDocument, &QAction::triggered, this, &Portal::slotOpenCurrentDocument);
     
-    newIcon = QIcon::fromTheme( "file-library-symbolic");
+    newIcon = DefaultProvider::self()->icon( "archive");
     _actOpenArchivedDocument = new QAction(newIcon, i18n("Open Archived Document"), this);
     _actOpenArchivedDocument->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_A ));
     connect(_actOpenArchivedDocument, &QAction::triggered, this, &Portal::slotArchivedDocExecuted);
 
-    newIcon = QIcon::fromTheme( "mail-forward");
+    newIcon = DefaultProvider::self()->icon("mail-forward");
     _actMailDocument = new QAction(newIcon, i18n("Mail Document"), this);
     _actMailDocument->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_M ));
     connect(_actMailDocument, &QAction::triggered, this, &Portal::slotMailDocument);
 
-    newIcon = QIcon::fromTheme( "mail-forward");
+    newIcon = DefaultProvider::self()->icon( "mail-forward");
     _actXRechnung = new QAction(newIcon, i18n("Export XRechnung"), this);
     _actXRechnung->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_R ));
     connect(_actXRechnung, &QAction::triggered, this, &Portal::slotXRechnungCurrentDocument);
 
-    newIcon = QIcon::fromTheme( "settings-configure");
+    newIcon = DefaultProvider::self()->icon( "settings");
     _actEditTemplates= new QAction(newIcon, i18n("Edit Tag Templates"), this);
     _actEditTemplates->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_E ));
     connect(_actEditTemplates, &QAction::triggered, this, &Portal::slotEditTagTemplates);
     
-    newIcon = QIcon::fromTheme( "settings-configure");
+    newIcon = DefaultProvider::self()->icon( "settings");
     _actReconfDb = new QAction(newIcon, i18n("Redo Initial Setup..."), this);
     _actReconfDb->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_R ));
     connect(_actReconfDb, &QAction::triggered, this, &Portal::slotReconfigureDatabase);
 
-    newIcon = QIcon::fromTheme( "help-about");
+    newIcon = DefaultProvider::self()->icon( "book");
     _actHandbook = new QAction(newIcon, i18n("Kraft Handbook..."), this);
     _actHandbook->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_H ));
     connect(_actHandbook, &QAction::triggered, this, &Portal::slotHandbook);
 
+    newIcon = DefaultProvider::self()->icon( "help");
     _actAboutQt = new QAction(newIcon, i18n("About Qt..."), this);
     _actAboutQt->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_Q ));
     connect(_actAboutQt, &QAction::triggered, this, &Portal::slotAboutQt);
 
+    newIcon = DefaultProvider::self()->icon( "kraft-simple");
     _actAboutKraft = new QAction(newIcon, i18n("About Kraft..."), this);
     _actAboutKraft->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_K ));
     connect(_actAboutKraft, &QAction::triggered, this, &Portal::slotAboutKraft);
@@ -396,6 +400,11 @@ void Portal::slotStartupChecks()
 
         slotStatusMsg( i18n( "Database Problem." ) );
     } else {
+        // if readonly, enable the change polling on the db
+        if (_readOnlyMode) {
+            KraftDB::self()->enableTimerRefresh(true);
+        }
+
         // Database interaction is ok after this point.
         m_portalView->slotBuildView();
         m_portalView->fillCatalogDetails();
@@ -704,6 +713,14 @@ void Portal::slotOpenArchivedDoc( const ArchDocDigest& d )
   busyCursor( false );
 }
 
+QDebug operator<<(QDebug debug, const dbID &id)
+{
+    QDebugStateSaver saver(debug);
+    debug.nospace().noquote()
+        << id.toString();
+    return debug;
+}
+
 void Portal::slotPrintCurrentDocument()
 {
   QString locId = m_portalView->docDigestView()->currentDocumentId();
@@ -719,6 +736,7 @@ void Portal::slotPrintCurrentDocument()
       ident = _currentDoc->ident();
 
       dbID archID = KraftDB::self()->archiveDocument(_currentDoc);
+      Q_ASSERT(archID.isOk());
       slotPrintDocument( ident, archID );
       // m_portalView->docDigestView()->addArchivedItem(docPtr->docID(), archID);
   }
@@ -749,9 +767,9 @@ void Portal::slotMailDocument()
   slotStatusMsg( i18n( "Ready." ) );
 }
 
-void Portal::slotDocConvertionFail(const QString& failString)
+void Portal::slotDocConvertionFail(const QString& failString, const QString& details)
 {
-    QMessageBox::warning(this, i18n("Doc Generation Error"),failString);
+    QMessageBox::warning(this, i18n("Doc Generation Error"), failString + "\n\n"+details);
 }
 
 void Portal::slotDocConverted(ReportFormat format, const QString& file, const KContacts::Addressee& customerContact)
@@ -771,7 +789,7 @@ void Portal::openInMailer(const QString& fileName, const KContacts::Addressee& c
     }
 
     QStringList args;
-    QString prog;
+    QString prog; // Use from system, we will not deliver them in an AppImage
 
     if( KraftSettings::self()->mailUA().startsWith("xdg") ) {
         args.append( "--utf8");
@@ -888,7 +906,7 @@ void Portal::slotDocumentSelected( const DocDigest& doc )
     } else {
         _actOpenArchivedDocument->setEnabled( enable );
         ArchDocDigest archDoc = archDocs.at(0);
-        _actXRechnung->setEnabled(archDoc.hasXRechnungExport() && enable);
+        _actXRechnung->setEnabled(archDoc.isInvoice() && enable);
     }
 }
 
