@@ -40,21 +40,18 @@
 #include "prefsdialog.h"
 #include "prefswages.h"
 #include "prefsunits.h"
-#include "databasesettings.h"
 #include "kraftsettings.h"
-#include "kraftdb.h"
-#include "kraftdoc.h"
 #include "defaultprovider.h"
 #include "doctype.h"
 #include "doctypeedit.h"
 #include "taxeditdialog.h"
-#include "documentman.h"
 #include "impviewwidgets.h"
 #include "texttemplate.h"
 #include "htmlview.h"
 #include "addressselectordialog.h"
 #include "addressprovider.h"
 #include "format.h"
+#include "positionviewwidget.h"
 
 #include "kcontacts/vcardconverter.h"
 
@@ -98,14 +95,14 @@ PrefsDialog::PrefsDialog( QWidget *parent)
 
   _maxNavBarTextWidth = 0;
 
-  addDialogPage( docTab(), QIcon::fromTheme( "edit-copy"), i18n( "Document Defaults" ));
-  addDialogPage( taxTab(), QIcon::fromTheme( "accessories-text-editor" ), i18n("Taxes"));
-  addDialogPage( doctypeTab(), QIcon::fromTheme( "folder-documents"), i18n( "Document Types" ));
+  addDialogPage( docTab(), DefaultProvider::self()->icon( "copy"), i18n( "Document Defaults" ));
+  addDialogPage( taxTab(), DefaultProvider::self()->icon( "receipt-tax" ), i18n("Taxes"));
+  addDialogPage( doctypeTab(), DefaultProvider::self()->icon( "files"), i18n( "Document Types" ));
   mPrefsWages = new PrefsWages(this);
-  addDialogPage(mPrefsWages, QIcon::fromTheme( "help-donate" ), i18n( "Wages" ));
+  addDialogPage(mPrefsWages, DefaultProvider::self()->icon( "cash-banknote" ), i18n( "Wages" ));
   mPrefsUnits = new PrefsUnits(this);
-  addDialogPage(mPrefsUnits, QIcon::fromTheme( "chronometer" ), i18n("Units"));
-  addDialogPage( whoIsMeTab(), QIcon::fromTheme( "user-identity" ), i18n( "Own Identity" ));
+  addDialogPage(mPrefsUnits, DefaultProvider::self()->icon( "atom" ), i18n("Units"));
+  addDialogPage( whoIsMeTab(), DefaultProvider::self()->icon( "id-badge-2" ), i18n( "Own Identity" ));
 
   readConfig();
 
@@ -182,11 +179,11 @@ QWidget* PrefsDialog::taxTab()
   QHBoxLayout *butLay = new QHBoxLayout;
   butLay->addStretch( 1 );
 
-  QPushButton *but = new QPushButton( QIcon::fromTheme("list-add"), i18n( "Add" ));
+  QPushButton *but = new QPushButton( DefaultProvider::self()->icon("plus"), i18n( "Add" ));
   connect( but, SIGNAL( clicked() ), SLOT( slotAddTax() ) );
   butLay->addWidget( but );
 
-  mDelTax = new QPushButton( QIcon::fromTheme("list-remove"), i18n( "Remove" ) );
+  mDelTax = new QPushButton( DefaultProvider::self()->icon("minus"), i18n( "Remove" ) );
   connect( mDelTax, SIGNAL( clicked() ), SLOT( slotDeleteTax() ) );
   butLay->addWidget( mDelTax );
   mDelTax->setEnabled( false );
@@ -244,6 +241,18 @@ QWidget* PrefsDialog::whoIsMeTab()
 
   _tabWidget->insertTab(1, w1, i18n("Manual Address"));
 
+  // == Bank Account information
+  QGroupBox *gbox = new QGroupBox(i18n("Bank Account Information"), this);
+  QFormLayout *formLayout = new QFormLayout;
+  _bacName = new QLineEdit(this);
+  formLayout->addRow(tr("&Bank Account Holder:"), _bacName);
+  _bacIBAN = new QLineEdit(this);
+  formLayout->addRow(tr("&IBAN:"), _bacIBAN);
+  _bacBIC = new QLineEdit(this);
+  formLayout->addRow(tr("&BIC:"), _bacBIC);
+  gbox->setLayout(formLayout);
+  vboxLay->addWidget(gbox);
+
   topWidget->setLayout( vboxLay );
 
   return topWidget;
@@ -348,6 +357,31 @@ QWidget* PrefsDialog::docTab()
   mCbDateFormats->insertItem( 5, i18n("Custom Setting in Settingsfile"));
   vboxLay->addLayout( butLay );
 
+  // ---- Alternative- and Demand Text
+  f = new QLabel(this);
+  f->setFrameStyle( QFrame::HLine | QFrame::Sunken );
+  vboxLay->addWidget( f );
+
+  auto gridLay = new QGridLayout;
+  l = new QLabel(i18n("Prefix text for Demand items:"), this );
+  gridLay->addWidget(l, 0, 0);
+
+  _lineEditDemandText = new QLineEdit(this);
+  _lineEditDemandText->setText(PositionViewWidget::kindLabel(PositionViewWidget::Demand));
+  _lineEditDemandText->setToolTip(i18n("This text is automatically prepended to new 'on demand' items."));
+
+  gridLay->addWidget(_lineEditDemandText, 0, 1);
+
+  l = new QLabel(i18n("Prefix text for Alternative items:"), this );
+  gridLay->addWidget(l, 1, 0);
+
+  _lineEditAlternativeText = new QLineEdit(this);
+  _lineEditAlternativeText->setText(PositionViewWidget::kindLabel(PositionViewWidget::Alternative));
+  _lineEditAlternativeText->setToolTip(i18n("This text is automatically prepended to new 'alternative' items."));
+
+  gridLay->addWidget(_lineEditAlternativeText, 1, 1);
+  vboxLay->addLayout( gridLay );
+
   // ---- XRechnung Template
   f = new QLabel(this);
   f->setFrameStyle( QFrame::HLine | QFrame::Sunken );
@@ -363,7 +397,7 @@ QWidget* PrefsDialog::docTab()
   QPushButton *pbXRechTmpl = new QPushButton(i18n("Select..."), this);
   butLay->addWidget(pbXRechTmpl);
 
-  const QIcon& icon = QIcon::fromTheme("quickopen-file");
+  const QIcon& icon = DefaultProvider::self()->icon("device-floppy");
   if (!icon.isNull() ) {
       pbXRechTmpl->setIcon(icon);
       pbXRechTmpl->setText("");
@@ -372,8 +406,8 @@ QWidget* PrefsDialog::docTab()
 
   connect(pbXRechTmpl, &QPushButton::clicked, this, [this]() {
       const QString file = QFileDialog::getOpenFileName(this,
-                                                  i18n("Find Template File"), QDir::homePath(),
-                                                  i18n("XRechnung Templates (*.xrtmpl)"));
+                                                        i18n("Find Template File"), QDir::homePath(),
+                                                        i18n("XRechnung Templates (*.xrtmpl)"));
 
       if (!file.isEmpty()) {
           _lineEditXRechnung->setText(file);
@@ -386,7 +420,7 @@ QWidget* PrefsDialog::docTab()
   spaceEater->setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding ) );
   vboxLay->addWidget( spaceEater );
 
-    return topWidget;
+  return topWidget;
 }
 
 QWidget* PrefsDialog::doctypeTab()
@@ -444,6 +478,7 @@ void PrefsDialog::readConfig()
     const auto tmpl = dt.xRechnungTemplate();
     _lineEditXRechnung->setText(tmpl);
 
+    // == Date format
     int index {5};
     const QString dFormat = KraftSettings::self()->dateFormat();
     if (dFormat == Format::DateFormatIso) {
@@ -474,6 +509,16 @@ void PrefsDialog::readConfig()
     }
 
     mCbDateFormats->setCurrentIndex(index);
+
+    // == Bank Account Information
+    QString h = KraftSettings::self()->bankAccountName();
+    _bacName->setText(h);
+    h = KraftSettings::self()->bankAccountBIC();
+    _bacBIC->setText(h);
+    h = KraftSettings::self()->bankAccountIBAN();
+    _bacIBAN->setText(h);
+
+
 }
 
 void PrefsDialog::writeIdentity()
@@ -540,6 +585,11 @@ void PrefsDialog::writeConfig()
         dt.save();
     }
 
+    const QString demandText = _lineEditDemandText->text();
+    KraftSettings::self()->setDemandLabel(demandText);
+    const QString alterText = _lineEditAlternativeText->text();
+    KraftSettings::self()->setAlternativeLabel(alterText);
+
     int dateFormat = mCbDateFormats->currentIndex();
 
     QString dateFormatString;
@@ -566,6 +616,19 @@ void PrefsDialog::writeConfig()
         KraftSettings::self()->setDateFormat(dateFormatString);
     }
 
+    QString h = _bacName->text();
+    if (h != KraftSettings::self()->bankAccountName()) {
+        KraftSettings::self()->setBankAccountName(h);
+    }
+    h = _bacBIC->text();
+    if (h != KraftSettings::self()->bankAccountBIC()) {
+        KraftSettings::self()->setBankAccountBIC(h);
+    }
+    h = _bacIBAN->text();
+    if (h != KraftSettings::self()->bankAccountIBAN()) {
+        KraftSettings::self()->setBankAccountIBAN(h);
+    }
+
     KraftSettings::self()->save();
 }
 
@@ -653,11 +716,11 @@ void PrefsDialog::setMyIdentity( const KContacts::Addressee& addressee, bool bac
       if( origin.isEmpty() || origin == "manual") {
           // it is an manually added address.
           fillManualIdentityForm(addressee);
-          _tabWidget->setTabIcon(1, QIcon::fromTheme("checkmark"));
+          _tabWidget->setTabIcon(1, DefaultProvider::self()->icon("check"));
           _tabWidget->setTabIcon(0, QIcon());
           _tabWidget->setCurrentIndex(1);
       } else {
-          _tabWidget->setTabIcon(0, QIcon::fromTheme("checkmark"));
+          _tabWidget->setTabIcon(0, DefaultProvider::self()->icon("check"));
           _tabWidget->setTabIcon(1, QIcon());
           _tabWidget->setCurrentIndex(0);
 
