@@ -93,20 +93,18 @@ int TemplKatalog::load()
   Katalog::load();
   int cnt = 0;
 
-  QString chapIdList;
-  bool firstOne = true;
-  foreach( CatalogChapter chap, mChapters ) {
-    if( !firstOne ) {
-      chapIdList += ",";
-    } else {
-      firstOne = false;
-    }
-    chapIdList += chap.id().toString();
+  if (mChapters.isEmpty())
+      getKatalogChapters(true);
+
+  QString chapIdList {"0"};
+  for( const CatalogChapter& chap : mChapters ) {
+      chapIdList.append(",");
+      chapIdList.append(chap.id().toString());
   }
 
   // qDebug () << "The chapterIdList: " << chapIdList;
   QSqlQuery q("SELECT unitID, TemplID, chapterID, Preisart, EPreis, modifyDatum, enterDatum, "
-              "Floskel, Gewinn, zeitbeitrag, lastUsed, useCounter FROM Catalog WHERE chapterID IN( " + chapIdList + ") "
+              "Floskel, Gewinn, zeitbeitrag FROM Catalog WHERE chapterID IN( " + chapIdList + ") "
               "ORDER BY chapterID, sortKey" );
   q.exec();
 
@@ -144,8 +142,9 @@ int TemplKatalog::load()
     bool tslice = q.value(9).toInt() > 0;
     flos->setHasTimeslice( tslice );
 
-    flos->setLastUsedDate( q.value(10).toDateTime() );
-    flos->setUseCounter( q.value(11).toInt() );
+    auto usage = usageCount(templID);
+    flos->setLastUsedDate(usage.second);
+    flos->setUseCounter(usage.first);
 
     loadCalcParts( flos );
 
@@ -154,31 +153,6 @@ int TemplKatalog::load()
   return cnt;
 }
 
-void TemplKatalog::recordUsage(int id)
-{
-    QSqlTableModel model;
-    model.setEditStrategy(QSqlTableModel::OnManualSubmit);
-    model.setTable("Catalog");
-    model.setFilter(QString("TemplID=%1").arg(id));
-    model.select();
-
-    if( model.rowCount() > 0) {
-        // qDebug () << "Updating template " << tmpl->getTemplID() << endl;
-        bool ok;
-        QSqlRecord buffer = model.record(0);
-        int currCnt = buffer.value("useCounter").toInt(&ok);
-        int newCnt = 0;
-        if (ok) {
-            newCnt = currCnt+1;
-        }
-        // mach update
-        buffer.setValue( "useCounter", newCnt);
-        buffer.setValue( "lastUsed", KraftDB::self()->currentTimeStamp() );
-        model.setRecord(0, buffer);
-        model.submitAll();
-    }
-}
-
 int TemplKatalog::addNewTemplate( FloskelTemplate *tmpl )
 {
   int re = -1;
@@ -219,6 +193,8 @@ void TemplKatalog::deleteTemplate( int id )
     q.exec();
     // qDebug () << "SQL Delete Success: " << q.lastError().text();
   }
+  deleteUsageRecord(id);
+
 }
 
 int TemplKatalog::loadCalcParts( FloskelTemplate *flos )
@@ -331,10 +307,9 @@ int TemplKatalog::loadFixCalcParts( FloskelTemplate *flos )
 }
 
 
-FloskelTemplateList TemplKatalog::getFlosTemplates( const CatalogChapter& chapter )
+FloskelTemplateList TemplKatalog::getFlosTemplates(int chapId)
 {
   FloskelTemplateList resultList;
-  int chap = chapter.id().toInt();
 
   if( m_flosList.count() == 0 )
   {
@@ -352,7 +327,7 @@ FloskelTemplateList TemplKatalog::getFlosTemplates( const CatalogChapter& chapte
     int haveChap = tmpl->chapterId().toInt();
 
     // qDebug() << "Searching for chapter " << chapter << " with ID " << chap << " and have " << haveChap << endl;
-    if( haveChap == chap )
+    if( haveChap == chapId )
     {
       resultList.append( tmpl );
     }
@@ -408,7 +383,7 @@ QDomDocument TemplKatalog::toXML()
     QDomElement rateelem = doc.createElement("rate");
     StdSatz satz = StdSatzMan::self()->getStdSatz(*it);
     Geld g = satz.getPreis();
-    QDomText rname = doc.createTextNode(g.toString());
+    QDomText rname = doc.createTextNode(g.toLocaleString());
     rateelem.appendChild(rname);
     set.appendChild(rateelem);
 
@@ -425,7 +400,7 @@ QDomDocument TemplKatalog::toXML()
     chapElem.appendChild(chapName);
     root.appendChild(chapElem);
 
-    FloskelTemplateList templs = getFlosTemplates(theChapter);
+    FloskelTemplateList templs = getFlosTemplates(theChapter.id().toInt());
     FloskelTemplateListIterator it(templs);
 
     // FIXME: XML export!
